@@ -506,6 +506,7 @@ void organ_vibrato::reset()
 {
     for (int i = 0; i < VibratoSize; i++)
         vibrato_x1[i][0] = vibrato_y1[i][0] = vibrato_x1[i][1] = vibrato_y1[i][1] = 0.f;
+    vibrato[0].a0 = vibrato[1].a0 = 0;
     lfo_phase = 0.f;
 }
 
@@ -551,7 +552,7 @@ void organ_vibrato::process(organ_parameters *parameters, float (*data)[2], unsi
 void organ_voice::update_pitch()
 {
     organ_voice_base::update_pitch();
-    dphase.set(dsp::midi_note_to_phase(note, 100 * parameters->global_transpose + parameters->global_detune, sample_rate) * parameters->pitch_bend);
+    dphase.set(dsp::midi_note_to_phase(note, 100 * parameters->global_transpose + parameters->global_detune, sample_rate) * inertia_pitchbend.get_last());
 }
 
 void organ_voice::render_block() {
@@ -567,9 +568,11 @@ void organ_voice::render_block() {
         return;
     }
 
+    inertia_pitchbend.set_inertia(parameters->pitch_bend);
+    inertia_pitchbend.step();
     update_pitch();
     dsp::fixed_point<int, 20> tphase, tdphase;
-    unsigned int foldvalue = parameters->foldvalue;
+    unsigned int foldvalue = parameters->foldvalue * inertia_pitchbend.get_last();
     int vibrato_mode = fastf2i_drm(parameters->lfo_mode);
     for (int h = 0; h < 9; h++)
     {
@@ -741,7 +744,7 @@ void drawbar_organ::update_params()
 
 void drawbar_organ::pitch_bend(int amt)
 {
-    parameters->pitch_bend = pow(2.0, amt * 2 / (12.0 * 8192));
+    parameters->pitch_bend = pow(2.0, (amt * parameters->pitch_bend_range) / (1200.0 * 8192.0));
     for (list<voice *>::iterator i = active_voices.begin(); i != active_voices.end(); i++)
     {
         organ_voice *v = dynamic_cast<organ_voice *>(*i);
@@ -765,7 +768,8 @@ void organ_voice_base::perc_note_on(int note, int vel)
     perc_reset();
     released_ref = false;
     this->note = note;
-    pamp.set(1.0f + (vel - 127) * parameters->percussion_vel2amp / 127.0);
+    if (parameters->percussion_level > 0)
+        pamp.set(1.0f + (vel - 127) * parameters->percussion_vel2amp / 127.0);
     update_pitch();
     float (*kt)[2] = parameters->percussion_keytrack;
     // assume last point (will be put there by padding)
